summaryrefslogtreecommitdiffstats
path: root/kchart
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitb6edfe41c9395f2e20784cbf0e630af6426950a3 (patch)
tree56ed9b871d4296e6c15949c24e16420be1b28697 /kchart
parentef39e8e4178a8f98cf5f154916ba0f03e4855206 (diff)
downloadkoffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.tar.gz
koffice-b6edfe41c9395f2e20784cbf0e630af6426950a3.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kchart')
-rw-r--r--kchart/csvimportdialog.cc2
-rw-r--r--kchart/kchartBackgroundPixmapConfigPage.cc20
-rw-r--r--kchart/kchartWizardSelectChartTypePage.cc2
-rw-r--r--kchart/kdchart/KDChart.cpp2
-rw-r--r--kchart/kdchart/KDChart.h2
-rw-r--r--kchart/kdchart/KDChartAxesPainter.cpp14
-rw-r--r--kchart/kdchart/KDChartAxisParams.cpp10
-rw-r--r--kchart/kdchart/KDChartBWPainter.cpp4
-rw-r--r--kchart/kdchart/KDChartDataIntern.h4
-rw-r--r--kchart/kdchart/KDChartDataRegion.h10
-rw-r--r--kchart/kdchart/KDChartLinesPainter.cpp8
-rw-r--r--kchart/kdchart/KDChartPainter.cpp8
-rw-r--r--kchart/kdchart/KDChartParams.cpp38
-rw-r--r--kchart/kdchart/KDChartParams.h8
-rw-r--r--kchart/kdchart/KDChartParams_io.cpp2
-rw-r--r--kchart/kdchart/KDChartPiePainter.cpp10
-rw-r--r--kchart/kdchart/KDChartRingPainter.cpp4
-rw-r--r--kchart/kdchart/KDChartWidget.cpp4
-rw-r--r--kchart/kdchart/KDDrawText.cpp6
-rw-r--r--kchart/kdchart/LICENSE4
20 files changed, 81 insertions, 81 deletions
diff --git a/kchart/csvimportdialog.cc b/kchart/csvimportdialog.cc
index 248719eb..1330ee88 100644
--- a/kchart/csvimportdialog.cc
+++ b/kchart/csvimportdialog.cc
@@ -378,7 +378,7 @@ void CSVImportDialog::fillTable( )
for (column = 0; column < m_dialog->m_sheet->numCols(); ++column)
{
const TQString header = m_dialog->m_sheet->horizontalHeader()->label(column);
- if ( m_formatList.tqfind( header ) == m_formatList.end() )
+ if ( m_formatList.find( header ) == m_formatList.end() )
m_dialog->m_sheet->horizontalHeader()->setLabel(column, i18n("Text"));
m_dialog->m_sheet->adjustColumn(column);
diff --git a/kchart/kchartBackgroundPixmapConfigPage.cc b/kchart/kchartBackgroundPixmapConfigPage.cc
index 825bca94..0f517ad6 100644
--- a/kchart/kchartBackgroundPixmapConfigPage.cc
+++ b/kchart/kchartBackgroundPixmapConfigPage.cc
@@ -194,19 +194,19 @@ void KChartBackgroundPixmapConfigPage::loadWallpaperFilesList()
if (imageCaption.isEmpty())
{
imageCaption = fileName;
- imageCaption.tqreplace('_', ' ');
+ imageCaption.replace('_', ' ');
imageCaption = KStringHandler::capwords(imageCaption);
}
// avoid name collisions
TQString rs = imageCaption;
TQString lrs = rs.lower();
- for (int n = 1; papers.tqfind(lrs) != papers.end(); ++n)
+ for (int n = 1; papers.find(lrs) != papers.end(); ++n)
{
rs = imageCaption + " (" + TQString::number(n) + ')';
lrs = rs.lower();
}
- int slash = (*it).tqfindRev('/') + 1;
+ int slash = (*it).findRev('/') + 1;
TQString directory = (*it).left(slash);
bool canLoadScaleable = false;
#ifdef HAVE_LIBART
@@ -233,8 +233,8 @@ void KChartBackgroundPixmapConfigPage::loadWallpaperFilesList()
if (imageCaption.isEmpty())
{
- int slash = (*it).tqfindRev('/') + 1;
- int endDot = (*it).tqfindRev('.');
+ int slash = (*it).findRev('/') + 1;
+ int endDot = (*it).findRev('.');
// strip the extension if it exists
if (endDot != -1 && endDot > slash)
@@ -242,14 +242,14 @@ void KChartBackgroundPixmapConfigPage::loadWallpaperFilesList()
else
imageCaption = (*it).mid(slash);
- imageCaption.tqreplace('_', ' ');
+ imageCaption.replace('_', ' ');
imageCaption = KStringHandler::capwords(imageCaption);
}
// avoid name collisions
TQString rs = imageCaption;
TQString lrs = rs.lower();
- for (int n = 1; papers.tqfind(lrs) != papers.end(); ++n)
+ for (int n = 1; papers.find(lrs) != papers.end(); ++n)
{
rs = imageCaption + " (" + TQString::number(n) + ')';
lrs = rs.lower();
@@ -455,12 +455,12 @@ void KChartBackgroundPixmapConfigPage::showSettings( const TQString& fileName )
{
wallCB->blockSignals(true);
- if (m_wallpaper.tqfind(fileName) == m_wallpaper.end())
+ if (m_wallpaper.find(fileName) == m_wallpaper.end())
{
int i = wallCB->count();
TQString imageCaption;
- int slash = fileName.tqfindRev('/') + 1;
- int endDot = fileName.tqfindRev('.');
+ int slash = fileName.findRev('/') + 1;
+ int endDot = fileName.findRev('.');
// strip the extension if it exists
if (endDot != -1 && endDot > slash)
diff --git a/kchart/kchartWizardSelectChartTypePage.cc b/kchart/kchartWizardSelectChartTypePage.cc
index 9cd2c4c8..ff2b8746 100644
--- a/kchart/kchartWizardSelectChartTypePage.cc
+++ b/kchart/kchartWizardSelectChartTypePage.cc
@@ -73,7 +73,7 @@ KChartWizardSelectChartTypePage::KChartWizardSelectChartTypePage( TQWidget* tqpa
addButton( i18n( "Ring" ), "chart_ring", KChartParams::Ring );
addButton( i18n( "Polar" ), "chart_polar", KChartParams::Polar);
- TQPushButton *current = ((TQPushButton*)m_typeBG->tqfind( m_chart->params()->chartType() ));
+ TQPushButton *current = ((TQPushButton*)m_typeBG->find( m_chart->params()->chartType() ));
if (current != NULL) {
current->setOn( true );
}
diff --git a/kchart/kdchart/KDChart.cpp b/kchart/kdchart/KDChart.cpp
index c7c80250..415f013a 100644
--- a/kchart/kdchart/KDChart.cpp
+++ b/kchart/kdchart/KDChart.cpp
@@ -58,7 +58,7 @@
\brief Provides a single entry-point to the charting engine for
applications that wish to provide their own TQPainter.
- It is not useful to instantiate this class as it tqcontains
+ It is not useful to instantiate this class as it contains
static methods only.
\note If for some reason you are NOT using the
diff --git a/kchart/kdchart/KDChart.h b/kchart/kdchart/KDChart.h
index 1f91f255..1510211e 100644
--- a/kchart/kdchart/KDChart.h
+++ b/kchart/kdchart/KDChart.h
@@ -43,7 +43,7 @@
\brief Definition of a single entry-point to the charting engine for
applications that wish to provide their own TQPainter.
- It is not useful to instantiate the KDChart class as it only tqcontains
+ It is not useful to instantiate the KDChart class as it only contains
static methods.
*/
diff --git a/kchart/kdchart/KDChartAxisParams.cpp b/kchart/kdchart/KDChartAxisParams.cpp
index 31ec8de4..a6e337f2 100644
--- a/kchart/kdchart/KDChartAxisParams.cpp
+++ b/kchart/kdchart/KDChartAxisParams.cpp
@@ -1933,7 +1933,7 @@ void KDChartAxisParams::setAxisValues( bool axisSteadyValueCalc,
with the next value lower than your start value that can be
divided by the delta factor.
- \param isExactValue set this to FALSE if KD Chart shall tqfind
+ \param isExactValue set this to FALSE if KD Chart shall find
a better value than the one you have specified by setAxisValueStart()
\sa setAxisValues, setAxisValueEnd, setAxisValueDelta
\sa axisValueStartIsExact, axisValueStart
@@ -2401,7 +2401,7 @@ void KDChartAxisParams::setAxisDtHighPos( double x, double y )
\note Calling this function results in overwriting the information
that you might have set by previous calls of that function.
Only <b>one</b> data row can be specified as containing label texts.
- To specify a data row that tqcontains (or might contain) axis label texts just
+ To specify a data row that contains (or might contain) axis label texts just
call this function with \c LabelsFromDataRowYes (or \c LabelsFromDataRowGuess,
resp.) specifying this row but do <b>not</b> call the function n times with
the \c LabelsFromDataRowNo parameter to 'deactivate' the other rows.
@@ -2409,7 +2409,7 @@ void KDChartAxisParams::setAxisDtHighPos( double x, double y )
the data rows is containing the axis label texts (this is the default
setting).
- \param row the data row number that tqcontains (or might contain, resp.) the labels
+ \param row the data row number that contains (or might contain, resp.) the labels
\param mode the state of our information concerning that row (see: \c LabelsFromDataRow)
\sa LabelsFromDataRow, axisLabelTextsFormDataRow, setAxisValues
@@ -2434,7 +2434,7 @@ void KDChartAxisParams::setLabelTextsFormDataRow( int row, LabelsFromDataRow mo
/**
\fn int KDChartAxisParams::labelTextsDataRow() const
- Returns the number of the data row that tqcontains (or might contain,
+ Returns the number of the data row that contains (or might contain,
resp.) the texts to be taken for the axis labels.
<br>
Use \c axisLabelTextsFormDataRow to make sure the texts are
@@ -2451,7 +2451,7 @@ void KDChartAxisParams::setLabelTextsFormDataRow( int row, LabelsFromDataRow mo
Use \c axisLabelTexts to get a TQStringList* containing the label
texts that are <b>actually</b> drawn at the axis.
- \return the number of the data row that tqcontains (or might contain,
+ \return the number of the data row that contains (or might contain,
resp.) the texts to be taken for the axis labels.
\sa setAxisValues
\sa axisValueStart, axisValueEnd
diff --git a/kchart/kdchart/KDChartBWPainter.cpp b/kchart/kdchart/KDChartBWPainter.cpp
index f376403b..9f6e5fb5 100644
--- a/kchart/kdchart/KDChartBWPainter.cpp
+++ b/kchart/kdchart/KDChartBWPainter.cpp
@@ -148,13 +148,13 @@ int KDChartBWPainter::calculateStats( KDChartTableDataBase& data,
(values[ TQMAX(nUd2-1, 0) ] + values[ nUd2 ]) /2;
// find last value of lower quartile
nLastQ1 = TQMAX( nUd2-1, 0 );
- // tqfind 1st value of lower quartile
+ // find 1st value of lower quartile
nFirstQ1 = nLastQ1 / 2;
// determine how many values are below the median ( == how many are above it)
int nLowerCount = nLastQ1 - nFirstQ1 + 1;
- // tqfind 1st value of upper quartile
+ // find 1st value of upper quartile
nFirstQ3 = bOdd ? TQMIN( nUd2+1, nUsed-1 ) : nUd2;
// find last value of upper quartile
nLastQ3 = nFirstQ3 + nLowerCount - 1;
diff --git a/kchart/kdchart/KDChartDataIntern.h b/kchart/kdchart/KDChartDataIntern.h
index 70cd3bda..a1d6562b 100644
--- a/kchart/kdchart/KDChartDataIntern.h
+++ b/kchart/kdchart/KDChartDataIntern.h
@@ -230,7 +230,7 @@ public:
}
}
}
- // Note: We do *not* compare the _propSetID here since it tqcontains
+ // Note: We do *not* compare the _propSetID here since it contains
// no values but is used to handle some tqlayout information...
}
return bRet;
@@ -288,7 +288,7 @@ public:
default:
/* NOOP */;
}
- // Note: We do *not* copy the _propSetID here since it tqcontains
+ // Note: We do *not* copy the _propSetID here since it contains
// no values but is used to handle some tqlayout information...
}
}
diff --git a/kchart/kdchart/KDChartDataRegion.h b/kchart/kdchart/KDChartDataRegion.h
index 13790435..c86d0bdc 100644
--- a/kchart/kdchart/KDChartDataRegion.h
+++ b/kchart/kdchart/KDChartDataRegion.h
@@ -137,23 +137,23 @@ struct KDCHART_EXPORT KDChartDataRegion
return TQRect();
}
- bool tqcontains(const TQPoint & p) const
+ bool contains(const TQPoint & p) const
{
if( pPointArrayList && ! pPointArrayList->empty() ){
PointArrayList::iterator it;
for ( it = pPointArrayList->begin(); it != pPointArrayList->end(); ++it ){
TQRegion region( *it );
- if( region.tqcontains( p ) )
+ if( region.contains( p ) )
return true;
}
return false;
}
if( pRegion )
- return pRegion->tqcontains( p );
+ return pRegion->contains( p );
if( pArray )
- return TQRegion( *pArray ).tqcontains( p );
+ return TQRegion( *pArray ).contains( p );
if( pRect )
- return pRect->tqcontains( p );
+ return pRect->contains( p );
return false;
}
diff --git a/kchart/kdchart/KDChartLinesPainter.cpp b/kchart/kdchart/KDChartLinesPainter.cpp
index aef52b79..a7e01092 100644
--- a/kchart/kdchart/KDChartLinesPainter.cpp
+++ b/kchart/kdchart/KDChartLinesPainter.cpp
@@ -509,7 +509,7 @@ void KDChartLinesPainter::specificPaintData( TQPainter* painter,
if( curPropSetId != KDChartPropertySet::UndefinedID ){
// we can safely call the following functions and ignore their
// return values since they will touch the parameters' values
- // if the propSet *tqcontains* corresponding own values only.
+ // if the propSet *contains* corresponding own values only.
int iDummy;
curPropSet.hasOwnShowMarker( iDummy, currentDrawMarkers );
}
@@ -554,7 +554,7 @@ void KDChartLinesPainter::specificPaintData( TQPainter* painter,
if( curPropSetId != KDChartPropertySet::UndefinedID ){
// we can safely call the following functions and ignore their
// return values since they will touch the parameters' values
- // if the propSet *tqcontains* corresponding own values only.
+ // if the propSet *contains* corresponding own values only.
int iDummy;
curPropSet.hasOwnMarkerAlign( iDummy, theAlignment );
curPropSet.hasOwnMarkerColor( iDummy, theColor );
@@ -658,7 +658,7 @@ void KDChartLinesPainter::specificPaintData( TQPainter* painter,
if( curPropSetId != KDChartPropertySet::UndefinedID ){
// we can safely call the following functions and ignore their
// return values since they will touch the parameters' values
- // if the propSet *tqcontains* corresponding own values only.
+ // if the propSet *contains* corresponding own values only.
int iDummy;
curPropSet.hasOwnAreaBrush( iDummy, theAreaBrush );
}
@@ -808,7 +808,7 @@ void KDChartLinesPainter::specificPaintData( TQPainter* painter,
if( curPropSetId != KDChartPropertySet::UndefinedID ){
// we can safely call the following functions and ignore their
// return values since they will touch the parameters' values
- // if the propSet *tqcontains* corresponding own values only.
+ // if the propSet *contains* corresponding own values only.
int iDummy;
curPropSet.hasOwnLineWidth ( iDummy, theLineWidth );
curPropSet.hasOwnLineColor ( iDummy, theLineColor );
diff --git a/kchart/kdchart/KDChartPainter.cpp b/kchart/kdchart/KDChartPainter.cpp
index 987857aa..156d5d82 100644
--- a/kchart/kdchart/KDChartPainter.cpp
+++ b/kchart/kdchart/KDChartPainter.cpp
@@ -494,7 +494,7 @@ void KDChartPainter::paintDataValues( TQPainter* painter,
region->text = "+LEMNISKATE";
else {
region->text.setNum( value, 'f', digits );
- if ( autoDigits && region->text.tqcontains( '.' ) ) {
+ if ( autoDigits && region->text.contains( '.' ) ) {
int len = region->text.length();
while ( 3 < len
&& '0' == region->text[ len-1 ]
@@ -518,7 +518,7 @@ void KDChartPainter::paintDataValues( TQPainter* painter,
region = regions->next() )
if ( ( ( lastDigitIrrelevant0 && !region->chart )
|| ( lastDigitIrrelevant1 && region->chart ) )
- && region->text.tqcontains( '.' )
+ && region->text.contains( '.' )
&& ( 2 < region->text.length() ) )
region->text.truncate ( region->text.length() - 2 );
@@ -1931,7 +1931,7 @@ void KDChartPainter::calculateAllAxesRects(
if( KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT == format )
areaMin = TQMAX( areaMin, static_cast < int > ( fntHeight * 6.75 ) );
else
- areaMin = TQMAX( areaMin, fntHeight * ( 3 + format.tqcontains("\n") ) );
+ areaMin = TQMAX( areaMin, fntHeight * ( 3 + format.contains("\n") ) );
}
else
areaMin = TQMAX( areaMin, fntHeight * 3 );
@@ -2851,7 +2851,7 @@ void KDChartPainter::drawExtraLinesAndMarkers(
// we can safely call the following functions and ignore their
// return values since they will touch the parameters' values
- // if the propSet *tqcontains* corresponding own values only.
+ // if the propSet *contains* corresponding own values only.
int iDummy;
uint extraLinesAlign = 0;
if( propSet.hasOwnExtraLinesAlign( iDummy, extraLinesAlign )
diff --git a/kchart/kdchart/KDChartParams.cpp b/kchart/kdchart/KDChartParams.cpp
index 7306cfe0..aac8928f 100644
--- a/kchart/kdchart/KDChartParams.cpp
+++ b/kchart/kdchart/KDChartParams.cpp
@@ -518,7 +518,7 @@ void KDChartParams::setProperties( int id, KDChartPropertySet& rSet )
{
_propertySetList.setAutoDelete( true );
rSet.mOwnID = id;
- _propertySetList.tqreplace( rSet.mOwnID, rSet.clone() );
+ _propertySetList.replace( rSet.mOwnID, rSet.clone() );
}
/**
@@ -568,7 +568,7 @@ bool KDChartParams::removeProperties( int id )
*/
bool KDChartParams::properties( int id, KDChartPropertySet& rSet ) const
{
- const KDChartPropertySet* R = _propertySetList.tqfind( id );
+ const KDChartPropertySet* R = _propertySetList.find( id );
const bool bFound = (0 != R);
if( bFound )
rSet.deepCopy( R );
@@ -600,7 +600,7 @@ bool KDChartParams::properties( int id, KDChartPropertySet& rSet ) const
*/
KDChartPropertySet* KDChartParams::properties( int id )
{
- return _propertySetList.tqfind( id );
+ return _propertySetList.find( id );
}
@@ -1514,7 +1514,7 @@ KDChartParams::SourceMode KDChartParams::chartSourceMode( uint dataset,
bool bStart = true;
ModeAndChartMap::ConstIterator it;
- for( it = _dataSourceModeAndChart.tqfind( a );
+ for( it = _dataSourceModeAndChart.find( a );
( it != _dataSourceModeAndChart.end() ) && ( it.key() <= b );
++it ){
if ( bStart ) {
@@ -1860,7 +1860,7 @@ void KDChartParams::calculateShadowColors( TQColor color,
TQColor KDChartParams::dataColor( uint dataset ) const
{
uint index = dataset % (_maxDatasetColor+1);
- if( _dataColors.tqfind( index ) != _dataColors.end() )
+ if( _dataColors.find( index ) != _dataColors.end() )
return _dataColors[ index ];
else
return TQColor(); // documentation says undefined
@@ -1916,12 +1916,12 @@ TQColor KDChartParams::dataShadow1Color( uint dataset ) const
{
uint index = dataset % _maxDatasetColor;
if ( _threeDShadowColors )
- if( _dataColorsShadow1.tqfind( index ) != _dataColorsShadow1.end() )
+ if( _dataColorsShadow1.find( index ) != _dataColorsShadow1.end() )
return _dataColorsShadow1[ index ];
else
return TQColor(); // documentation says undefined
else
- if( _dataColors.tqfind( index ) != _dataColors.end() )
+ if( _dataColors.find( index ) != _dataColors.end() )
return _dataColors[ index ];
else
return TQColor(); // documentation says undefined
@@ -1945,12 +1945,12 @@ TQColor KDChartParams::dataShadow2Color( uint dataset ) const
{
uint index = dataset % _maxDatasetColor;
if ( _threeDShadowColors )
- if( _dataColorsShadow2.tqfind( index ) != _dataColorsShadow2.end() )
+ if( _dataColorsShadow2.find( index ) != _dataColorsShadow2.end() )
return _dataColorsShadow2[ index ];
else
return TQColor(); // documentation says undefined
else
- if( _dataColors.tqfind( index ) != _dataColors.end() )
+ if( _dataColors.find( index ) != _dataColors.end() )
return _dataColors[ index ];
else
return TQColor(); // documentation says undefined
@@ -2572,7 +2572,7 @@ bool KDChartParams::moveDataRegionFrame( uint oldDataRow,
)
{
const TQString oldKey( dataRegionFrameAreaName( oldDataRow, oldDataCol, 0 ) ); // oldData3rd ) );
- KDChartFrameSettings* it = _areaDict.tqfind( oldKey );
+ KDChartFrameSettings* it = _areaDict.find( oldKey );
bool bFound = ( it != 0 );
if( bFound ){
if( KDCHART_NO_DATASET != newDataRow ){
@@ -2582,7 +2582,7 @@ bool KDChartParams::moveDataRegionFrame( uint oldDataRow,
frame->setDataCol( newDataCol );
frame->setData3rd( 0 ); // newData3rd );
_areaDict.setAutoDelete( TRUE );
- _areaDict.tqreplace(
+ _areaDict.replace(
dataRegionFrameAreaName( newDataRow, newDataCol, 0 ), //data3rd 5 ),
frame );
}
@@ -2610,7 +2610,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
if( pIterIdx )
*pIterIdx = 0;
const TQString key( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
- KDChartFrameSettings* it = _areaDict.tqfind( key );
+ KDChartFrameSettings* it = _areaDict.find( key );
bFound = ( it != 0 );
if( bFound )
return it;
@@ -2698,7 +2698,7 @@ uint KDChartParams::insertCustomBox( const KDChartCustomBox & box )
const uint maxIndex = maxCustomBoxIdx();
newIdx = 1 + maxIndex;
for( uint idx = 0; idx <= maxIndex; ++idx ) {
- if( ! _customBoxDict.tqfind( idx ) ) {
+ if( ! _customBoxDict.find( idx ) ) {
newIdx = idx;
_customBoxDictMayContainHoles = true; // we found a hole, so there might be more of them
break;
@@ -2758,7 +2758,7 @@ bool KDChartParams::removeCustomBox( const uint & idx )
*/
const KDChartCustomBox* KDChartParams::customBox( uint box ) const
{
- return _customBoxDict.tqfind( box );
+ return _customBoxDict.find( box );
}
/**
@@ -2776,7 +2776,7 @@ const KDChartCustomBox* KDChartParams::customBox( uint box ) const
*/
KDChartCustomBox* KDChartParams::customBoxRef( uint box )
{
- return _customBoxDict.tqfind( box );
+ return _customBoxDict.find( box );
}
/**
@@ -4685,7 +4685,7 @@ void KDChartParams::setLineMarkerStyle( uint dataset, LineMarkerStyle style )
*/
KDChartParams::LineMarkerStyle KDChartParams::lineMarkerStyle( uint dataset ) const
{
- if( _lineMarkerStyles.tqfind( dataset ) != _lineMarkerStyles.end() )
+ if( _lineMarkerStyles.find( dataset ) != _lineMarkerStyles.end() )
return _lineMarkerStyles[ dataset ];
else
return LineMarkerCircle; // default
@@ -4891,7 +4891,7 @@ Qt::PenStyle KDChartParams::lineStyle( uint dataset ) const
if( KDCHART_GLOBAL_LINE_STYLE == dataset )
// global line style
return _lineStyle;
- else if( _datasetLineStyles.tqfind( dataset ) == _datasetLineStyles.end() )
+ else if( _datasetLineStyles.find( dataset ) == _datasetLineStyles.end() )
return lineStyle();
else
return _datasetLineStyles[ dataset ];
@@ -5197,7 +5197,7 @@ void KDChartParams::setPolarMarkerStyle( uint dataset, PolarMarkerStyle style )
*/
KDChartParams::PolarMarkerStyle KDChartParams::polarMarkerStyle( uint dataset ) const
{
- if( _polarMarkerStyles.tqfind( dataset ) != _polarMarkerStyles.end() )
+ if( _polarMarkerStyles.find( dataset ) != _polarMarkerStyles.end() )
return _polarMarkerStyles[ dataset ];
else
return PolarMarkerCircle; // default
@@ -6729,7 +6729,7 @@ void KDChartParams::setBWChartPrintStatistics( BWStatVal statValue,
<li>Manual - Uses texts set with setLegendText(); if no text is set for
a dataset, the legend text will be empty.
<li>FirstColumn - Uses values from the first column, no matter what
- this tqcontains.
+ this contains.
<li>Automatic - Tries first to use values from the first column; if
this does not contain any string values, tries to use values set
manually with setLegendText(). If there are no values set manually
diff --git a/kchart/kdchart/KDChartParams.h b/kchart/kdchart/KDChartParams.h
index 7196ef2c..7ae8c27c 100644
--- a/kchart/kdchart/KDChartParams.h
+++ b/kchart/kdchart/KDChartParams.h
@@ -393,7 +393,7 @@ public slots:
bool addFrameHeightToLayout = true )
{
_areaDict.setAutoDelete( TRUE );
- _areaDict.tqreplace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
new KDChartFrameSettings(0,0,0,
frame,
outerGapX,
@@ -436,7 +436,7 @@ public slots:
shadowWidth,
sunPos );
- _areaDict.tqreplace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
new KDChartFrameSettings( 0,0,0, frame,
outerGapX,
outerGapY,
@@ -477,7 +477,7 @@ public slots:
shadowWidth,
sunPos );
- _areaDict.tqreplace(
+ _areaDict.replace(
dataRegionFrameAreaName( dataRow, dataCol, 0 ), //data3rd 5 ),
new KDChartFrameSettings( dataRow,
dataCol,
@@ -1924,7 +1924,7 @@ public slots:
TQString legendText( uint dataset ) const
{
- if( _legendText.tqfind( dataset ) != _legendText.end() )
+ if( _legendText.find( dataset ) != _legendText.end() )
return _legendText[ dataset ];
else
return TQString();
diff --git a/kchart/kdchart/KDChartParams_io.cpp b/kchart/kdchart/KDChartParams_io.cpp
index e24ce590..2feaf179 100644
--- a/kchart/kdchart/KDChartParams_io.cpp
+++ b/kchart/kdchart/KDChartParams_io.cpp
@@ -2200,7 +2200,7 @@ bool KDChartParams::loadXML( const TQDomDocument& doc )
.tqarg( 0, 5 );//frameSettings->data3rd(), 5 );
else
str = TQString( "%1/-----/-----/-----" ).tqarg( areaId, 5 );
- _areaDict.tqreplace( str, frameSettings );
+ _areaDict.replace( str, frameSettings );
}
}
else
diff --git a/kchart/kdchart/KDChartPiePainter.cpp b/kchart/kdchart/KDChartPiePainter.cpp
index dd00f627..ada03b44 100644
--- a/kchart/kdchart/KDChartPiePainter.cpp
+++ b/kchart/kdchart/KDChartPiePainter.cpp
@@ -241,7 +241,7 @@ void KDChartPiePainter::paintData( TQPainter* painter,
// take one pie from the stack
int currentpie = todostack.pop();
// if this pie was already drawn, ignore it
- if ( donelist.tqfind( currentpie ) != donelist.end() )
+ if ( donelist.find( currentpie ) != donelist.end() )
continue;
// If this pie is the frontmost pie, put it back, but at the
@@ -278,10 +278,10 @@ void KDChartPiePainter::paintData( TQPainter* painter,
// whether these have not been painted already, and put them
// on the stack.
int leftOfCurrent = findLeftPie( currentpie );
- if ( donelist.tqfind( leftOfCurrent ) == donelist.end() )
+ if ( donelist.find( leftOfCurrent ) == donelist.end() )
todostack.push( leftOfCurrent );
int rightOfCurrent = findRightPie( currentpie );
- if ( donelist.tqfind( rightOfCurrent ) == donelist.end() )
+ if ( donelist.find( rightOfCurrent ) == donelist.end() )
todostack.push( rightOfCurrent );
}
@@ -326,7 +326,7 @@ void KDChartPiePainter::drawOnePie( TQPainter* painter,
// need to compute a new position for each or some of the pie
TQValueList<int> explodeList = params()->explodeValues();
if( explodeList.count() == 0 || // nothing on list, explode all
- explodeList.tqfind( pie ) != explodeList.end() ) {
+ explodeList.find( pie ) != explodeList.end() ) {
double explodeAngle = ( startAngle + angleLen / 2 ) / 16;
double explodeAngleRad = DEGTORAD( explodeAngle );
double cosAngle = cos( explodeAngleRad );
@@ -335,7 +335,7 @@ void KDChartPiePainter::drawOnePie( TQPainter* painter,
// find the explode factor for this particular pie
double explodeFactor = 0.0;
TQMap<int,double> explodeFactors = params()->explodeFactors();
- if( !explodeFactors.tqcontains( pie ) ) // not on factors list, use default
+ if( !explodeFactors.contains( pie ) ) // not on factors list, use default
explodeFactor = params()->explodeFactor();
else // on factors list, use segment-specific value
explodeFactor = explodeFactors[pie];
diff --git a/kchart/kdchart/KDChartRingPainter.cpp b/kchart/kdchart/KDChartRingPainter.cpp
index d9016ed3..9740fa5e 100644
--- a/kchart/kdchart/KDChartRingPainter.cpp
+++ b/kchart/kdchart/KDChartRingPainter.cpp
@@ -203,7 +203,7 @@ void KDChartRingPainter::paintData( TQPainter* painter,
bool explode = params()->explode() && // explosion is on at all
( dataset == (int)datasetStart ) && // outermost ring
( ( explodeList.count() == 0 ) || // either nothing on explode list
- ( explodeList.tqfind( value ) != explodeList.end() ) ); // or pie is on it
+ ( explodeList.find( value ) != explodeList.end() ) ); // or pie is on it
drawOneSegment( painter,
currentouterradius,
@@ -253,7 +253,7 @@ void KDChartRingPainter::drawOneSegment( TQPainter* painter,
// find the explode factor for this particular ring segment
double explodeFactor = 0.0;
TQMap<int,double> explodeFactors = params()->explodeFactors();
- if( !explodeFactors.tqcontains( value ) ) // not on factors list, use default
+ if( !explodeFactors.contains( value ) ) // not on factors list, use default
explodeFactor = params()->explodeFactor();
else // on factors list, use segment-specific value
explodeFactor = explodeFactors[value];
diff --git a/kchart/kdchart/KDChartWidget.cpp b/kchart/kdchart/KDChartWidget.cpp
index 00e4a45c..c3e42b8b 100644
--- a/kchart/kdchart/KDChartWidget.cpp
+++ b/kchart/kdchart/KDChartWidget.cpp
@@ -168,7 +168,7 @@ void KDChartWidget::mousePressEvent( TQMouseEvent* event )
//TQPtrListIterator < KDChartDataRegion > it( _dataRegions );
for( current = _dataRegions.last(); current; current = _dataRegions.prev() ){
//while ( ( current = it.current() ) ) {
- if ( current->tqcontains( event->pos() ) ) {
+ if ( current->contains( event->pos() ) ) {
_mousePressedOnRegion = current;
if ( event->button() == Qt::LeftButton ){
emit dataLeftPressed( current->row, current->col );
@@ -198,7 +198,7 @@ void KDChartWidget::mouseReleaseEvent( TQMouseEvent* event )
TQPtrListIterator < KDChartDataRegion > it( _dataRegions );
while ( ( current = it.current() ) ) {
++it;
- if ( current->tqcontains( event->pos() ) ) {
+ if ( current->contains( event->pos() ) ) {
if ( event->button() == Qt::LeftButton ) {
emit dataLeftReleased( current->row, current->col );
emit dataLeftReleased( event->pos() );
diff --git a/kchart/kdchart/KDDrawText.cpp b/kchart/kdchart/KDDrawText.cpp
index 2ef93088..a954a5bf 100644
--- a/kchart/kdchart/KDDrawText.cpp
+++ b/kchart/kdchart/KDDrawText.cpp
@@ -163,13 +163,13 @@ void KDDrawText::drawRotatedTxt( TQPainter* painter,
pFM = const_cast<TQFontMetrics*>(fontMet);
}
- int nLF = text.tqcontains('\n');
+ int nLF = text.contains('\n');
if( INT_MAX == txtWidth ) {
if( nLF ){
int tw;
txtWidth = 0;
int i0 = 0;
- int iLF = text.tqfind('\n');
+ int iLF = text.find('\n');
while( -1 != iLF ){
const TQRect r(pFM->boundingRect( text.mid(i0, iLF-i0) ));
tw = r.width()+ 2;
@@ -177,7 +177,7 @@ void KDDrawText::drawRotatedTxt( TQPainter* painter,
if( tw > txtWidth )
txtWidth = tw;
i0 = iLF+1;
- iLF = text.tqfind('\n', i0);
+ iLF = text.find('\n', i0);
}
if( iLF < (int)text.length() ){
const TQRect r(pFM->boundingRect( text.mid( i0 ) ));
diff --git a/kchart/kdchart/LICENSE b/kchart/kdchart/LICENSE
index 0d0f1cfa..8d0b8788 100644
--- a/kchart/kdchart/LICENSE
+++ b/kchart/kdchart/LICENSE
@@ -67,7 +67,7 @@ modification follow.
GNU GENERAL PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
- 0. This License applies to any program or other work which tqcontains
+ 0. This License applies to any program or other work which contains
a notice placed by the copyright holder saying it may be distributed
under the terms of this General Public License. The "Program", below,
refers to any such program or work, and a "work based on the Program"
@@ -162,7 +162,7 @@ Sections 1 and 2 above provided that you also do one of the following:
The source code for a work means the preferred form of the work for
making modifications to it. For an executable work, complete source
-code means all the source code for all modules it tqcontains, plus any
+code means all the source code for all modules it contains, plus any
associated interface definition files, plus the scripts used to
control compilation and installation of the executable. However, as a
special exception, the source code distributed need not include
diff --git a/kchart/kdchart/KDChartAxesPainter.cpp b/kchart/kdchart/KDChartAxesPainter.cpp
index 4c592ea6..6124abe8 100644
--- a/kchart/kdchart/KDChartAxesPainter.cpp
+++ b/kchart/kdchart/KDChartAxesPainter.cpp
@@ -2479,7 +2479,7 @@ void KDChartAxesPainter::calculateLabelTexts(
modf( ddelta, &ddelta );
bool positive = ( 0.0 <= ddelta );
int delta = static_cast < int > ( fabs( ddelta ) );
// tqfind 1st significant entry
TQStringList::Iterator it = positive
? tmpList.begin()
: tmpList.fromLast();
@@ -3663,7 +3663,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
//qDebug("nVal: %f sVal: "+sVal, nVal );
//qDebug( TQString(" %1").tqarg(sVal));
if ( bUseAutoDigits ) {
- int comma = sVal.tqfind( '.' );
+ int comma = sVal.find( '.' );
if ( -1 < comma ) {
if ( bAutoDelta ) {
int i = sVal.length();
@@ -3684,7 +3684,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
if ( '.' == sDelta[ i - 1 ] )
trueBehindComma = 0;
else {
- int deltaComma = sDelta.tqfind( '.' );
+ int deltaComma = sDelta.find( '.' );
if ( -1 < deltaComma )
trueBehindComma = sDelta.length() - deltaComma - 1;
else
@@ -3753,9 +3753,9 @@ TQString KDChartAxesPainter::applyLabelsFormat( const double nVal_,
trueBehindComma );
//qDebug("sVal : "+sVal+" behindComma: %i",behindComma);
- int posComma = sVal.tqfind( '.' );
+ int posComma = sVal.find( '.' );
if( 0 <= posComma ){
- sVal.tqreplace( posComma, 1, decimalPoint);
+ sVal.replace( posComma, 1, decimalPoint);
}else{
posComma = sVal.length();
}
@@ -3795,7 +3795,7 @@ TQString KDChartAxesPainter::applyLabelsFormat( const double nVal_,
*and the user has set axisLabelsDigitsBehindComma() == 0
*return an empty string
*/
- if ( behindComma == 0 && TQString::number(nVal).tqfind('.') > 0 )
+ if ( behindComma == 0 && TQString::number(nVal).find('.') > 0 )
sVal = TQString();//sVal = "";
return sVal;
}
@@ -3854,7 +3854,7 @@ void KDChartAxesPainter::calculateOrdinateFactors(
if ( 100.0 > nDist )
nDivisor = 1.0;
else {
- int comma = sDistDigis2.tqfind( '.' );
+ int comma = sDistDigis2.find( '.' );
if ( -1 < comma )
sDistDigis2.truncate( comma );
nDivisor = fastPow10( (int)sDistDigis2.length() - 2 );
@@ -2479,7 +2479,7 @@ void KDChartAxesPainter::calculateLabelTexts(
bool positive = ( 0.0 <= ddelta );
int delta = static_cast < int > ( fabs( ddelta ) );
- // tqfind 1st significant entry
+ // find 1st significant entry
TQStringList::Iterator it = positive
? tmpList.begin()